summaryrefslogtreecommitdiffstats
path: root/player/core.h
diff options
context:
space:
mode:
authorwm4 <wm4@nowhere>2014-10-21 13:16:48 +0200
committerwm4 <wm4@nowhere>2014-10-21 13:19:20 +0200
commitf0f83ff36600abc8715f3a11c31b2eeeda6c8c92 (patch)
tree38c6faba94976b08052fed67615d6680c748022e /player/core.h
parentbcc3d72995e926f899c0baa215599c50e23b9523 (diff)
downloadmpv-f0f83ff36600abc8715f3a11c31b2eeeda6c8c92.tar.bz2
mpv-f0f83ff36600abc8715f3a11c31b2eeeda6c8c92.tar.xz
player: add stream selection by ffmpeg index
Apparently using the stream index is the best way to refer to the same streams across multiple FFmpeg-using programs, even if the stream index itself is rarely meaningful in any way. For Matroska, there are some possible problems, depending how FFmpeg actually adds streams. Normally they seem to match though.
Diffstat (limited to 'player/core.h')
-rw-r--r--player/core.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/player/core.h b/player/core.h
index 4d4142000c..f883ae2882 100644
--- a/player/core.h
+++ b/player/core.h
@@ -96,8 +96,8 @@ struct track {
// IDs coming from demuxers or container files.
int user_tid;
- // Same as stream->demuxer_id. -1 if not set.
- int demuxer_id;
+ int demuxer_id; // same as stream->demuxer_id. -1 if not set.
+ int ff_index; // same as stream->ff_index, or 0.
char *title;
bool default_track;